@@ -57,9 +57,6 @@ class Query():
         for folder in [Query.music_folder]:
             if os.path.islink(folder):
                 logger.warn("%s is a symlink, this folder will be omitted", folder)
-            else:
-                i = len(next(os.walk(folder)))
-                logger.debug("Found %d files in %s", i, folder)
 
     def __repr__(self):
         return '<Query>'
@@ -211,13 +208,15 @@ class Query():
         query = """
     SELECT DISTINCT
         rdf:type(?song)
+        ?song AS ?tracker_urn
         tracker:id (?song) AS ?id
         ?url
         nie:title(?song) AS ?title
         nmm:artistName(nmm:performer(?song)) AS ?artist
         nie:title(nmm:musicAlbum(?song)) AS ?album
         nfo:duration(?song) AS ?duration
-        IF (BOUND(?tag), 'b', '') AS ?lyrics
+        ?tag AS ?favourite
+        nie:usageCounter(?song) AS ?play_count
     {
         %(where_clause)s
         ?song a nmm:MusicPiece ;
@@ -266,6 +265,7 @@ class Query():
         query = """
     SELECT DISTINCT
         rdf:type(?song)
+        ?song AS ?tracker_urn
         tracker:id(?song) AS ?id
         nie:url(?song) AS ?url
         nie:title(?song) AS ?title
@@ -274,13 +274,14 @@ class Query():
         nfo:duration(?song) AS ?duration
         nmm:trackNumber(?song) AS ?track_number
         nmm:setNumber(nmm:musicAlbumDisc(?song)) AS ?album_disc_number
-        IF(bound(?tag), 'truth!', '') AS ?lyrics
+        ?tag AS ?favourite
+        nie:usageCounter(?song) AS ?play_count
     WHERE {
         ?song a nmm:MusicPiece ;
               a nfo:FileDataObject ;
               nmm:musicAlbum ?album .
         OPTIONAL { ?song nao:hasTag ?tag .
-                   FILTER( ?tag = nao:predefined-tag-favorite ) } .
+                   FILTER (?tag = nao:predefined-tag-favorite) } .
         FILTER (tracker:id(?album) = %(album_id)s &&
                 (STRSTARTS(nie:url(?song), '%(music_dir)s/')))
     }
@@ -300,13 +301,15 @@ class Query():
         query = """
     SELECT
         rdf:type(?song)
+        ?song AS ?tracker_urn
         tracker:id(?entry) AS ?id
         nie:url(?song) AS ?url
         nie:title(?song) AS ?title
         nmm:artistName(nmm:performer(?song)) AS ?artist
         nie:title(nmm:musicAlbum(?song)) AS ?album
         nfo:duration(?song) AS ?duration
-        IF(bound(?tag), 'truth!', '') AS ?lyrics
+        ?tag AS ?favourite
+        nie:usageCounter(?song) AS ?play_count
     WHERE {
         ?playlist a nmm:Playlist ;
             a nfo:MediaList ;
@@ -404,45 +407,6 @@ class Query():
         }
         return query
 
-    @staticmethod
-    def update_playcount(song_url):
-        query = """
-    INSERT OR REPLACE { ?song nie:usageCounter ?playcount . }
-    WHERE {
-        SELECT
-            IF(bound(?usage), (?usage + 1), 1) AS ?playcount
-            ?song
-            WHERE {
-                ?song a nmm:MusicPiece .
-                OPTIONAL { ?song nie:usageCounter ?usage . }
-                FILTER ( nie:url(?song) = "%(song_url)s" )
-            }
-        }
-    """.replace("\n", " ").strip() % {
-            'song_url': song_url
-        }
-
-        return query
-
-    @staticmethod
-    def update_last_played(song_url, time):
-        query = """
-    INSERT OR REPLACE { ?song nfo:fileLastAccessed '%(time)s' . }
-    WHERE {
-        SELECT
-            ?song
-            WHERE {
-                ?song a nmm:MusicPiece .
-                FILTER ( nie:url(?song) = "%(song_url)s" )
-            }
-        }
-    """.replace("\n", " ").strip() % {
-            'song_url': song_url,
-            'time': time
-        }
-
-        return query
-
     @staticmethod
     def create_playlist(title):
         query = """
@@ -755,7 +719,7 @@ class Query():
             WHERE {
                 ?song a nmm:MusicPiece ;
                     nie:isStoredAs ?as ;
-                    nfo:fileLastAccessed ?last_played .
+                    nie:contentAccessed ?last_played .
                 ?as nie:url ?url .
                 FILTER ( ?last_played > '%(compare_date)s'^^xsd:dateTime
                          && EXISTS { ?song nie:usageCounter ?count .}
@@ -1029,39 +993,6 @@ class Query():
 
         return query
 
-    @staticmethod
-    def add_favorite(song_url):
-        query = """
-            INSERT {
-                ?song nao:hasTag nao:predefined-tag-favorite
-            }
-            WHERE {
-                ?song a nmm:MusicPiece .
-                FILTER ( nie:url(?song) = "%(song_url)s" )
-            }
-        """.replace("\n", " ").strip() % {
-            'song_url': song_url
-
-        }
-
-        return query
-
-    @staticmethod
-    def remove_favorite(song_url):
-        query = """
-            DELETE {
-                ?song nao:hasTag nao:predefined-tag-favorite
-            }
-            WHERE {
-                ?song a nmm:MusicPiece .
-                FILTER ( nie:url(?song) = "%(song_url)s" )
-            }
-        """.replace("\n", " ").strip() % {
-            'song_url': song_url
-        }
-
-        return query
-
     @staticmethod
     def is_audio(media_id):
         query = """
