@@ -29,9 +29,7 @@
 # code, but you are not obligated to do so.  If you do not wish to do so,
 # delete this exception statement from your version.
 
-import gi
-gi.require_version('Gd', '1.0')
-from gi.repository import Gtk, Gdk, Gio, GLib, Gd
+from gi.repository import Gtk, Gdk, Gio, GLib
 from gettext import gettext as _, ngettext
 
 from gnomemusic import log
@@ -81,10 +79,10 @@ class Window(Gtk.ApplicationWindow):
         self.set_size_request(200, 100)
         self.set_icon_name('gnome-music')
         self.notification_handler = None
+        self._loading_counter = 0
 
         self.prev_view = None
         self.curr_view = None
-        self.pl_todelete_notification = None
 
         size_setting = self.settings.get_value('window-size')
         if isinstance(size_setting[0], int) and isinstance(size_setting[1], int):
@@ -100,12 +98,102 @@ class Window(Gtk.ApplicationWindow):
             self.maximize()
 
         self._setup_view()
+        self._setup_loading_notification()
+        self._setup_playlist_notification()
 
         self.window_size_update_timeout = None
         self.connect("window-state-event", self._on_window_state_event)
         self.connect("configure-event", self._on_configure_event)
         grilo.connect('changes-pending', self._on_changes_pending)
 
+    @log
+    def _setup_loading_notification(self):
+        self._loading_notification = Gtk.Revealer(
+                       halign=Gtk.Align.CENTER, valign=Gtk.Align.START)
+        self._loading_notification.set_transition_type(
+                                 Gtk.RevealerTransitionType.SLIDE_DOWN)
+        self._overlay.add_overlay(self._loading_notification)
+
+        def hide_notification_cb(button, self):
+            self._loading_notification.set_reveal_child(False)
+
+        grid = Gtk.Grid(margin_bottom=18, margin_start=18, margin_end=18)
+        grid.set_column_spacing(18)
+        grid.get_style_context().add_class('app-notification')
+
+        spinner = Gtk.Spinner()
+        spinner.start()
+        grid.add(spinner)
+
+        label = Gtk.Label.new(_("Loading"))
+        grid.add(label)
+
+        button = Gtk.Button.new_from_icon_name('window-close-symbolic',
+                                               Gtk.IconSize.BUTTON)
+        button.get_style_context().add_class('flat')
+        button.connect('clicked', hide_notification_cb, self)
+        grid.add(button)
+
+        self._loading_notification.add(grid)
+        self._loading_notification.show_all()
+
+    @log
+    def _setup_playlist_notification(self):
+        self._playlist_notification_timeout_id = 0
+        self._playlist_notification = Gtk.Revealer(halign=Gtk.Align.CENTER,
+                                                   valign=Gtk.Align.START)
+        self._playlist_notification.set_transition_type(
+                       Gtk.RevealerTransitionType.SLIDE_DOWN)
+        self._overlay.add_overlay(self._playlist_notification)
+
+        grid = Gtk.Grid(margin_bottom=18, margin_start=18, margin_end=18)
+        grid.set_column_spacing(12)
+        grid.get_style_context().add_class('app-notification')
+
+        def remove_notification_timeout(self):
+            # Remove the timeout if any
+            if self._playlist_notification_timeout_id > 0:
+                GLib.source_remove(self._playlist_notification_timeout_id)
+                self._playlist_notification_timeout_id = 0
+
+        # Hide the notification and delete the playlist
+        def hide_notification_cb(button, self):
+            self._playlist_notification.set_reveal_child(False)
+
+            if self.views[3].really_delete:
+                playlist.delete_playlist(self.views[3].pl_todelete)
+            else:
+                self.views[3].really_delete = True
+
+            remove_notification_timeout(self)
+
+        # Undo playlist removal
+        def undo_remove_cb(button, self):
+            self.views[3].really_delete = False
+            self._playlist_notification.set_reveal_child(False)
+            self.views[3].undo_playlist_deletion()
+
+            remove_notification_timeout(self)
+
+        # Playlist name label
+        self._playlist_notification.label = Gtk.Label('')
+        grid.add(self._playlist_notification.label)
+
+        # Undo button
+        undo_button = Gtk.Button.new_with_mnemonic(_("_Undo"))
+        undo_button.connect("clicked", undo_remove_cb, self)
+        grid.add(undo_button)
+
+        # Close button
+        button = Gtk.Button.new_from_icon_name('window-close-symbolic',
+                                               Gtk.IconSize.BUTTON)
+        button.get_style_context().add_class('flat')
+        button.connect('clicked', hide_notification_cb, self)
+        grid.add(button)
+
+        self._playlist_notification.add(grid)
+        self._playlist_notification.show_all()
+
     @log
     def _on_changes_pending(self, data=None):
         def songs_available_cb(available):
@@ -302,69 +390,40 @@ class Window(Gtk.ApplicationWindow):
             view = self._stack.get_visible_child().get_visible_child()
             view.select_none()
 
-    def _show_notification(self):
-        self.notification_handler = None
-        self.notification.show_all()
-        return False
-
     @log
-    def _init_loading_notification(self):
-        self.notification = Gd.Notification()
-        self.notification.set_timeout(5)
-        grid = Gtk.Grid(valign=Gtk.Align.CENTER, margin_end=8)
-        grid.set_column_spacing(8)
-        spinner = Gtk.Spinner()
-        spinner.start()
-        grid.add(spinner)
-        label = Gtk.Label.new(_("Loading"))
-        grid.add(label)
-        self.notification.add(grid)
-        self._overlay.add_overlay(self.notification)
-        if self.notification_handler:
-            GLib.Source.remove(self.notification_handler)
-            self.notification_handler = None
-        self.notification_handler = GLib.timeout_add(1000, self._show_notification)
+    def show_playlist_notification(self):
+        """Show a notification on playlist removal and provide an
+        option to undo for 5 seconds.
+        """
 
-    @log
-    def _init_playlist_removal_notification(self):
-        if self.pl_todelete_notification:
+        # Callback to remove playlists
+        def remove_playlist_timeout_cb(self):
+            # Remove the playlist
             self.views[3].really_delete = False
-            self.pl_todelete_notification.destroy()
             playlist.delete_playlist(self.views[3].pl_todelete)
 
-        self.notification = Gd.Notification()
-        self.notification.set_timeout(20)
+            # Hide the notification
+            self._playlist_notification.set_reveal_child(False)
 
-        grid = Gtk.Grid(valign=Gtk.Align.CENTER, margin_right=8)
-        grid.set_column_spacing(8)
-        self.notification.add(grid)
+            # Stop the timeout
+            self._playlist_notification_timeout_id = 0
 
-        undo_button = Gtk.Button.new_with_mnemonic(_("_Undo"))
-        label = _("Playlist %s removed" % (
-            self.views[3].current_playlist.get_title()))
-        grid.add(Gtk.Label.new(label))
-        grid.add(undo_button)
+            return GLib.SOURCE_REMOVE
 
-        self.notification.show_all()
-        self._overlay.add_overlay(self.notification)
-        self.pl_todelete_notification = self.notification
+        # If a notification is already visible, remove that playlist
+        if self._playlist_notification_timeout_id > 0:
+            GLib.source_remove(self._playlist_notification_timeout_id)
+            remove_playlist_timeout_cb(self)
 
-        self.notification.connect("dismissed", self._playlist_removal_notification_dismissed)
-        undo_button.connect("clicked", self._undo_deletion)
+        playlist_title = self.views[3].current_playlist.get_title()
+        label = _("Playlist {} removed".format(playlist_title))
 
-    @log
-    def _playlist_removal_notification_dismissed(self, widget):
-        self.pl_todelete_notification = None
-        if self.views[3].really_delete:
-            playlist.delete_playlist(self.views[3].pl_todelete)
-        else:
-            self.views[3].really_delete = True
+        self._playlist_notification.label.set_label(label)
+        self._playlist_notification.set_reveal_child(True)
 
-    @log
-    def _undo_deletion(self, widget):
-        self.views[3].really_delete = False
-        self.notification.dismiss()
-        self.views[3].undo_playlist_deletion()
+        timeout_id = GLib.timeout_add_seconds(5, remove_playlist_timeout_cb,
+                                              self)
+        self._playlist_notification_timeout_id = timeout_id
 
     @log
     def _on_key_press(self, widget, event):
@@ -536,3 +595,37 @@ class Window(Gtk.ApplicationWindow):
             self.toolbar.set_selection_mode(False)
 
         self._stack.get_visible_child().get_selected_tracks(callback)
+
+    @log
+    def push_loading_notification(self):
+        """ Increases the counter of loading notification triggers
+        running. If there is no notification is visible, the loading
+        notification is started.
+        """
+        def show_notification_cb(self):
+            self._loading_notification.set_reveal_child(True)
+            self._show_notification_timeout_id = 0
+            return GLib.SOURCE_REMOVE
+
+        if self._loading_counter == 0:
+            # Only show the notification after a small delay, thus
+            # add a timeout. 500ms feels good enough.
+            self._show_notification_timeout_id = GLib.timeout_add(
+                    500, show_notification_cb, self)
+
+        self._loading_counter = self._loading_counter + 1
+
+    @log
+    def pop_loading_notification(self):
+        """ Decreases the counter of loading notification triggers
+        running. If it reaches zero, the notification is withdrawn.
+        """
+        self._loading_counter = self._loading_counter - 1
+
+        if self._loading_counter == 0:
+            # Remove the previously set timeout, if any
+            if self._show_notification_timeout_id > 0:
+                GLib.source_remove(self._show_notification_timeout_id)
+                self._show_notification_timeout_id = 0
+
+            self._loading_notification.set_reveal_child(False)
